@@ -6,6 +6,7 @@ import unittest
 
 import gi.overrides
 import gi.module
+import gi.importer
 
 try:
     from gi.repository import Regress
@@ -14,7 +15,8 @@ except ImportError:
     Regress = None
 
 
-class TestRegistry(unittest.TestCase):
+class TestOverrides(unittest.TestCase):
+
     def test_non_gi(self):
         class MyClass:
             pass
@@ -31,6 +33,29 @@ class TestRegistry(unittest.TestCase):
         # https://bugzilla.gnome.org/show_bug.cgi?id=680913
         self.assertEqual(Regress.REGRESS_OVERRIDE, 42)
 
+    def test_load_overrides(self):
+        mod = gi.module.get_introspection_module('GIMarshallingTests')
+        mod_override = gi.overrides.load_overrides(mod)
+        self.assertTrue(mod_override is not mod)
+        self.assertTrue(mod_override._introspection_module is mod)
+        self.assertEqual(mod_override.OVERRIDES_CONSTANT, 7)
+        self.assertEqual(mod.OVERRIDES_CONSTANT, 42)
+
+    def test_load_no_overrides(self):
+        mod_key = "gi.overrides.GIMarshallingTests"
+        had_mod = mod_key in sys.modules
+        old_mod = sys.modules.get(mod_key)
+        try:
+            # this makes override import fail
+            sys.modules[mod_key] = None
+            mod = gi.module.get_introspection_module('GIMarshallingTests')
+            mod_override = gi.overrides.load_overrides(mod)
+            self.assertTrue(mod_override is mod)
+        finally:
+            del sys.modules[mod_key]
+            if had_mod:
+                sys.modules[mod_key] = old_mod
+
 
 class TestModule(unittest.TestCase):
     # Tests for gi.module
@@ -49,12 +74,6 @@ class TestModule(unittest.TestCase):
         mod2 = gi.module.get_introspection_module(mod_name)
         self.assertTrue(mod1 is mod2)
 
-        # Using a DynamicModule will use get_introspection_module internally
-        # in its _load method.
-        mod_overridden = gi.module.DynamicModule(mod_name)
-        mod_overridden._load()
-        self.assertTrue(mod1 is mod_overridden._introspection_module)
-
         # Restore the previous cache
         gi.module._introspection_modules = old_modules
 
@@ -98,3 +117,26 @@ class TestImporter(unittest.TestCase):
             self.assertTrue('introspection typelib' not in exception_string)
         else:
             self.assertTrue('introspection typelib' in exception_string)
+
+    def test__get_all_dependencies(self):
+        get_all_dependencies = gi.importer._get_all_dependencies
+        deps = set(get_all_dependencies("Regress"))
+
+        self.assertTrue('Gio-2.0' in deps)
+        self.assertTrue('GObject-2.0' in deps)
+        self.assertTrue('GLib-2.0' in deps)
+        self.assertTrue('cairo-1.0' in deps)
+
+    def test_require_version_warning(self):
+        check = gi.importer._check_require_version
+
+        # make sure it doesn't fail at least
+        with check("GLib", 1):
+            from gi.repository import GLib
+            GLib
+
+        # make sure the exception propagates
+        with self.assertRaises(ImportError):
+            with check("InvalidGObjectRepositoryModuleName", 1):
+                from gi.repository import InvalidGObjectRepositoryModuleName
+                InvalidGObjectRepositoryModuleName
